import React, { useState, useEffect, useRef, ChangeEvent } from 'react';

const defaultProps = {
  placeholder: 'Algum texto',
  value: '',
  height: 'auto',
  acceptValue: false,
  textAreaWidth: '10em',
  setChange: (event: ChangeEvent<HTMLTextAreaElement>) => {
    console.log(event);
  },
  borderColor: '#4F4F4F',
};

type TextAreaProps = {
  placeholder?: string;
  value?: string;
  height?: string;
  acceptValue?: boolean;
  textAreaWidth?: string;
  setChange?: (event: ChangeEvent<HTMLTextAreaElement>) => void;
  borderColor?: string;
} & typeof defaultProps;

function TextArea(props: TextAreaProps) {
  const {
    placeholder,
    textAreaWidth,
    value,
    height,
    setChange,
    borderColor,
    acceptValue,
  } = props;

  const textAreaRef = useRef<HTMLTextAreaElement>(null);
  const [text, setText] = useState('');
  const [textAreaHeight, setTextAreaHeight] = useState(height);
  const [parentHeight, setParentHeight] = useState(height);

  useEffect(() => {
    setParentHeight(`${textAreaRef.current?.scrollHeight}px`);
    setTextAreaHeight(`${textAreaRef.current?.scrollHeight}px`);
  }, [text]);

  const onChangeHandler = (event: React.ChangeEvent<HTMLTextAreaElement>) => {
    setTextAreaHeight('auto');
    setParentHeight(`${textAreaRef.current?.scrollHeight}px`);
    setText(event.target.value);
  };

  const styles = {
    textArea: {
      margin: '0.5em',
      fontStyle: 'roboto',
      border: '0.1em solid',
      borderColor: `${borderColor}`,
      borderRadius: '0.3em',
      width: '85%',
      height: textAreaHeight,
      overflow: 'hidden',
      padding: '1.0625rem 0.875rem 1.0625rem 1.0625rem',
      minWidth: '20.1875rem',
      maxWidth: '66.8rem',
      minHeight: height,
    },
  };

  return (
    <div
      style={{
        minHeight: parentHeight,
        display: 'flex',
        justifyContent: 'center',
      }}
    >
      {acceptValue ? (
        <textarea
          ref={textAreaRef}
          rows={1}
          value={value}
          style={styles.textArea}
          onChange={e => {
            setChange(e);
            onChangeHandler(e);
          }}
          placeholder={placeholder}
        />
      ) : (
        <textarea
          ref={textAreaRef}
          rows={1}
          style={styles.textArea}
          onChange={e => {
            setChange(e);
            onChangeHandler(e);
          }}
          placeholder={placeholder}
        />
      )}
    </div>
  );
}

TextArea.defaultProps = defaultProps;

export default TextArea;
