import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard } from '../components';
import TitleComponent from '../components/TitleComponent';
import { CardLista, Header } from '../containers';
import { Student, StudentData } from '../model/student';
import { getStudentById } from '../services/student';
import { getAllData } from '../services/studentData';
import colors from '../utils/colors';

import fontawesome from '../utils/fontawesome';

function AreaAluno() {
  const { id } = useParams();
  const navigate = useNavigate();
  const [studentData, setStudentData] = useState<Student>();
  const [data, setData] = useState<StudentData[]>();

  useEffect(() => {
    const getStudent = async (id: number) => {
      try {
        const getStudentsResponse: Student = await getStudentById(id);
        setStudentData(getStudentsResponse);
      } catch (err) {
        console.log(err);
      }
    };
    const getAllStudentData = async (studentId: number) => {
      try {
        const getDataResponse: StudentData[] = await getAllData(studentId);
        setData(getDataResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      getStudent(Number(id));
      getAllStudentData(Number(id));
    }
  }, []);

  const getAge = (birthString: string) => {
    if (birthString) {
      const birthDate = new Date(birthString);
      const now = new Date();
      let finalAge = now.getFullYear() - birthDate.getFullYear();
      const month = now.getMonth() - birthDate.getMonth();
      if (month < 0 || (month === 0 && now.getDate() < birthDate.getDate())) {
        finalAge--;
      }

      return `${finalAge} anos`;
    }
    return '';
  };

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={styles.titleContainer}>
        <TitleComponent
          text={`${studentData?.name}`}
          textAlign="left"
          fontWeight="600"
          textSize="1.75rem"
          subtitle={getAge(studentData?.birth_date as string)}
        />
      </div>

      <div style={styles.buttonsContainer}>
        <div>
          <ButtonCard
            iconWidth="100%"
            text="Relatorio"
            icon={fontawesome.icons.faFilePen}
            width="8.75rem"
            height="8.75rem"
            sizeIcon="4em"
            display="block"
          />
        </div>
        <div>
          <ButtonCard
            iconWidth="100%"
            text="Anotações"
            icon={fontawesome.icons.faNoteSticky}
            width="8.75rem"
            height="8.75rem"
            sizeIcon="4em"
            display="block"
          />
        </div>
      </div>

      <div>
        <div style={{ marginTop: '0.8rem', paddingLeft: '1.5rem' }}>
          <TitleComponent
            text="Dados do aluno"
            textAlign="left"
            textSize="1.7rem"
            fontWeight="600"
          />
        </div>
        <div
          style={{
            margin: '0.8rem 1.5rem 1.7rem 1.5rem',
          }}
        >
          <ButtonCard
            icon={fontawesome.icons.faSquarePlus}
            text="Adicionar Característica"
            width="100%"
            sizeIcon="3em"
            onClick={() =>
              navigate(`/area-aluno/${studentData?.id}/cadastrar-dado`)
            }
          />
        </div>
        <div style={styles.dataList}>
          {data?.map(data => (
            <div key={data.id} style={styles.card}>
              <CardLista
                enableIconArrow={false}
                enableTag={false}
                enableSubtitle2={false}
                titleContent={data.subject}
                subtitle1Content={data.content}
                onClickPen={() =>
                  navigate(
                    `/area-aluno/${studentData?.id}/cadastrar-dado/${data.id}`,
                  )
                }
              />
            </div>
          ))}
        </div>
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'flex-start',
    paddingTop: '7.688rem',
    paddingLeft: '1.5rem',
  },
  buttonsContainer: {
    display: 'flex',
    justifyContent: 'space-around' as const,
  },
  dataList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
};

export default AreaAluno;
