import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import CardLista from '../containers/CardLista';
import Header from '../containers/Header';
import { Student } from '../model/student';
import { User, UserType } from '../model/user';
import { getAllStudents, getAllStudentsByTeacher } from '../services/student';
import colors from '../utils/colors';

const defaultProps = {
  isCoordinator: false,
};

type studentListScreenProps = {
  isCoordinator?: boolean;
} & typeof defaultProps;

function StudentList({ isCoordinator }: studentListScreenProps) {
  const navigate = useNavigate();
  const [students, setStudents] = useState<Student[]>([]);

  useEffect(() => {
    const getStudents = async () => {
      try {
        const currentSession = sessionStorage.getItem('user');
        let getStudentsResponse: Student[];
        const userSession: User = JSON.parse(currentSession || '{}');
        if (userSession.type === UserType.TEACHER) {
          getStudentsResponse = await getAllStudentsByTeacher(userSession.id);
        } else {
          getStudentsResponse = await getAllStudents();
        }
        setStudents(getStudentsResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getStudents();
  }, []);

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Lista de Alunos" disableArrow enableLogout />
      </div>
      <div style={styles.studentList}>
        {students.length !== 0 ? (
          students.map(student => {
            return (
              <div key={student.id} style={styles.card}>
                <CardLista
                  titleContent={student.name}
                  subtitle1Content="Turma 1"
                  enableIconPen={isCoordinator}
                  enableIconArrow={!isCoordinator}
                  enableSubtitle2={false}
                  enableTag={false}
                  onClickPen={() => navigate(`/editar-aluno/${student.id}`)}
                  onClickArrow={() => navigate(`/area-aluno/${student.id}`)}
                />
              </div>
            );
          })
        ) : (
          <div style={styles.card}>
            <div>Nao tem nenhum aluno cadastrado</div>
          </div>
        )}
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  studentList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  card: {
    marginBottom: '1.438rem',
    width: '20.188rem',
  },
};

StudentList.defaultProps = defaultProps;

export default StudentList;
