import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React, { useEffect, useState } from 'react';

import { useNavigate } from 'react-router-dom';
import { TextField } from '../components';
import TitleComponent from '../components/TitleComponent';
import CardLista from '../containers/CardLista';
import Header from '../containers/Header';
import { User } from '../model/user';
import { getAllUsers } from '../services/user';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

function UserList() {
  // { userArray }: UserListProps
  const navigate = useNavigate();
  const [searchName, setSearchName] = useState<string>('');

  // Cuida dos users vindos do back
  const [users, setUsers] = useState<User[]>([]);
  // Cuida da filtragem desse Users
  const [filteredUsers, setFilteredUsers] = useState<User[]>(users);

  useEffect(() => {
    const getUsers = async () => {
      try {
        const getUserResponse: User[] = await getAllUsers();
        setUsers(getUserResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getUsers();
  }, []);

  const userArrayHandler = (event: React.ChangeEvent<HTMLInputElement>) => {
    const searchedUserName: string = event.target.value;
    const newFilteredUsers: User[] = users.filter(testUser =>
      testUser.name.toLowerCase().includes(searchedUserName.toLowerCase()),
    );
    setSearchName(searchedUserName);
    setFilteredUsers(newFilteredUsers);
  };

  const renderUser = (user: User): JSX.Element => {
    const typeLabels: Record<string, string> = {
      COORDINATOR: 'Coordenador',
      TEACHER: 'Professor',
      RESPONSIBLE: 'Responsável',
      SPECIALIST: 'Especialista',
    };
    return (
      <div key={user.id} style={styles.card}>
        <CardLista
          titleContent={user.name}
          subtitle1Content={typeLabels[user.type]}
          enableIconArrow={false}
          enableSubtitle2={false}
          enableTag={false}
        />
      </div>
    );
  };

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Coordenador" disableArrow enableLogout />
      </div>
      <div style={styles.titleContainer}>
        <TitleComponent
          text="Buscar Usuário"
          fontWeight="600"
          textSize="1.75rem"
        />
        <FontAwesomeIcon
          icon={fontawesome.icons.faSquarePlus}
          style={styles.icon}
          onClick={() => navigate('/cadastro-professor')}
        />
      </div>
      <div style={styles.searchBar}>
        <TextField
          placeholder="Buscar..."
          margin="0px"
          borderRadius="30px"
          disableIcon={false}
          onChange={userArrayHandler}
        />
      </div>

      <div style={styles.userList}>
        {filteredUsers.length !== 0 ? (
          filteredUsers.slice(0, 11).map(user => renderUser(user))
        ) : (
          <div style={styles.card}>
            <CardLista
              titleContent={
                users.length !== 0
                  ? `O usuário ${
                      searchName.length >= 12
                        ? `${searchName.slice(0, 11)}...`
                        : searchName
                    } não foi encontrado`
                  : `Nenhum usuário foi cadastrado`
              }
              enableIconArrow={false}
              enableIconPen={false}
              enableSubtitle1={false}
              enableSubtitle2={false}
              enableTag={false}
              disableTitleCenter={false}
              textColor={colors.theme.cancel}
            />
          </div>
        )}
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  searchBar: {
    display: 'flex',
    justifyContent: 'center',
  },
  icon: {
    fontSize: '2rem',
    marginLeft: '1.75rem',
    cursor: 'pointer',
    paddingTop: '0.3rem',
  },
  userList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
};

export default UserList;
